import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/InvoiceSaleSettings/commodityCost";

import dayjs from "dayjs";
import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { good_type } from "./configs";

function renderGoodImage(imgSrc: string) {
  const imgs = imgSrc.split(",");
  return h(ElImage, {
    src: imgs[0],
    previewTeleported: true,
    previewSrcList: [imgs[0]],
    style: {
      height: "20px"
    }
  });
}

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "商品编码",
    prop: "spuCode"
  },
  {
    label: "供应商编号",
    prop: "supplierNo"
  },
  {
    label: "业务企业编号",
    prop: "companyNo"
  },
  {
    label: "商品名称",
    prop: "good_name"
  },
  {
    label: "商品主图",
    prop: "good_img",
    cellRenderer: ({ row }) => renderGoodImage(row.good_img)
  },
  {
    label: "类目名称",
    prop: "inv_cat_name"
  },
  {
    label: "开票商品名称",
    prop: "inv_good_name"
  },
  {
    label: "创建人",
    prop: "creater"
  },
  {
    label: "状态",
    prop: "status",
    cellRenderer: ({ row }) => {
      return h(ElTag, null, {
        default: () => good_type.find(t => t.value === row.status)?.label
      });
    }
  },
  {
    label: "创建时间",
    prop: "createTime",
    formatter: ({ createTime }) =>
      dayjs(createTime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    width: 80,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "销售成本类目设置",
  columns,
  apis: {
    httpList
  },
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"]
};

export default contentConfig;
