import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/InvoiceSales/returnTicket";
import { httpAdd } from "/@/api/InvoiceSales/returnTicket";

import dayjs from "dayjs";
import { ElTag } from "element-plus";
import { h } from "vue";
import { return_status } from "/@/utils/details/inv-return";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "退票编号",
    prop: "returnCode"
  },
  {
    label: "付款单位名称",
    prop: "buyer_title"
  },
  {
    label: "付款银行名称",
    prop: "buyer_bank"
  },
  {
    label: "付款账号",
    prop: "inv_value"
  },
  {
    label: "收款单位名称",
    prop: "inv_in"
  },
  {
    label: "申请时间",
    prop: "addtime",
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "状态",
    prop: "status",
    cellRenderer: ({ row }) => {
      return h(ElTag, null, {
        default: () => return_status.find(s => s.value === row.status)?.label
      });
    }
  },
  {
    label: "操作",
    fixed: "right",
    width: 80,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "退票申请管理",
  powers: ["001", "002", "003", "004", "005", "006", "007", "008"],
  columns,
  mockData: [
    {
      buyer_title: "泰康人寿保险有限责任公司大连分公司",
      buyer_code: "91210200736420120U",
      buyer_addr: "辽宁省大连市中山区五五路4A号上方港景A座32层",
      buyer_mobile: "0411-82800287",
      buyer_bank: "中国建设银行大连人民路支行",
      buyer_bankNo: "21201500250053000712",
      seller_title: "北京万宇恒通国际科贸有限公司",
      seller_code: "91110113MA004JNJ28",
      seller_addr: "北京市顺义区信中街12号院8号楼-1至4层101内三层309室",
      seller_mobile: "010-69464815",
      seller_bank: "中国农业银行股份有限公司北京空港支行",
      seller_bankNo: "11120901040013561",
      voider: " ",
      payee: " ",
      drawer: " ",
      reviewer: " ",
      ownerPlace: " ",
      inv_value: "650.00",
      inv_out: "GS2203161855277894",
      inv_in: "KH2206091605154719",
      inv_type: 1,
      open_type: 2,
      is_ticket: 0,
      email: "",
      winv_fee: "650.00",
      ainv_fee: "0.00",
      post_fee: "26.00",
      post_company: "顺丰快递",
      post_code: "SF12321321312312",
      id: 1,
      returnCode: "RIN2207271638256857",
      invNo: "INV2207271542474795",
      return_reason: "开多票",
      return_type: 1,
      remark: "退票",
      status: "2",
      red_inv: "hc1213213321",
      apply_id: 44,
      apply_name: "吴广广",
      addtime: "2022-07-27 16:38:25",
      updatetime: "2022-07-27 16:47:31"
    }
  ],
  apis: {
    httpList,
    httpAdd
  }
};

export default contentConfig;
